@@ -21,7 +21,7 @@ package Bio::DB::HTS::Tabix;
 
 use Bio::DB::HTS; #load the XS
 use Bio::DB::HTS::Tabix::Iterator;
-$Bio::DB::HTS::Tabix::VERSION = '1.08';
+$Bio::DB::HTS::Tabix::VERSION = '1.09';
 use strict;
 use warnings;
 
@@ -95,6 +95,12 @@ sub seqnames {
     return tbx_seqnames($self->{_tabix_index});
 }
 
+sub header {
+    my $self = shift;
+    return $self->{_header};
+}
+
+
 #free up memory allocated in XS code
 sub DEMOLISH {
     my $self = shift;
